package com.ruoyi.cs.mapper;

import java.util.List;
import com.ruoyi.cs.domain.CsOpenRecord;

/**
 * 开户记录Mapper接口
 * 
 * @author ruoyi
 * @date 2024-05-29
 */
public interface CsOpenRecordMapper 
{
    /**
     * 查询开户记录
     * 
     * @param openRecordId 开户记录主键
     * @return 开户记录
     */
    public CsOpenRecord selectCsOpenRecordByOpenRecordId(String openRecordId);

    /**
     * 查询开户记录列表
     * 
     * @param csOpenRecord 开户记录
     * @return 开户记录集合
     */
    public List<CsOpenRecord> selectCsOpenRecordList(CsOpenRecord csOpenRecord);

    /**
     * 新增开户记录
     * 
     * @param csOpenRecord 开户记录
     * @return 结果
     */
    public int insertCsOpenRecord(CsOpenRecord csOpenRecord);

    /**
     * 修改开户记录
     * 
     * @param csOpenRecord 开户记录
     * @return 结果
     */
    public int updateCsOpenRecord(CsOpenRecord csOpenRecord);

    /**
     * 删除开户记录
     * 
     * @param openRecordId 开户记录主键
     * @return 结果
     */
    public int deleteCsOpenRecordByOpenRecordId(String openRecordId);

    /**
     * 批量删除开户记录
     * 
     * @param openRecordIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCsOpenRecordByOpenRecordIds(String[] openRecordIds);

    /**
     * 查询到期的开户记录列表
     *
     * @return
     */
    List<CsOpenRecord> searchOpenRecordList();

}
